@@ -7,7 +7,6 @@ utils::globalVariables(c(".", "%>%", ":="))
   
   # set number of threads used in data.table to 100% 
   data.table::setDTthreads(percent = 100) # nocov
-  
 }
 
 #' @importFrom magrittr %>%
@@ -17,6 +16,7 @@ utils::globalVariables(c(".", "%>%", ":="))
 #' @importFrom stats na.omit
 #' @importFrom Rcpp compileAttributes
 #' @importFrom lwgeom st_geod_length
+#' @importFrom rgdal readOGR
 #' @useDynLib gtfs2gps, .registration = TRUE
 NULL
 
@@ -29,4 +29,5 @@ if(getRversion() >= "2.15.1") utils::globalVariables(
     '.N', 'update_newstoptimes', 'shape_pt_sequence', 'geometry',
     'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday',
     'service_duration', 'headway_secs', 'number_of_departures',
-    'cumtime', 'speed', 'i'))
+    'cumtime', 'speed', 'i', 'route_type',
+    '.I', 'interval_id', 'i.interval', '.SD', 'grp', '.GRP'))
